@@ -40,8 +40,7 @@ extern "C" {
 #  define MRN_HANDLER_CLONE_NEED_NAME 1
 #endif
 
-#if (MYSQL_VERSION_ID >= 50603) || \
-    (MYSQL_VERSION_ID >= 50514)
+#if (MYSQL_VERSION_ID >= 50514 && MYSQL_VERSION_ID < 50600)
 #  define MRN_HANDLER_HAVE_FINAL_ADD_INDEX 1
 #endif
 
@@ -64,6 +63,14 @@ extern "C" {
 #  define MRN_HANDLER_HAVE_MULTI_RANGE_READ 1
 #endif
 
+#if (MYSQL_VERSION_ID >= 50607)
+// TODO
+#  define MRN_HANDLER_HAVE_CHECK_IF_SUPPORTED_INPLACE_ALTER 1
+#  define MRN_HANDLER_HAVE_HA_PREPARE_INPLACE_ALTER_TABLE 1
+#  define MRN_HANDLER_HAVE_HA_INPLACE_ALTER_TABLE 1
+#  define MRN_HANDLER_HAVE_HA_COMMIT_INPLACE_ALTER_TABLE 1
+#endif
+
 #ifndef MRN_MARIADB_P
 #  define MRN_HANDLER_HAVE_INDEX_READ_LAST_MAP
 #endif
@@ -91,12 +98,6 @@ extern "C" {
 #  define MRN_HA_ROWS_FORMAT "lu"
 #endif
 
-#if MYSQL_VERSION_ID >= 50604
-#  define MRN_HAVE_MYSQL_TYPE_TIMESTAMP2
-#  define MRN_HAVE_MYSQL_TYPE_DATETIME2
-#  define MRN_HAVE_MYSQL_TYPE_TIME2
-#endif
-
 #if (MYSQL_VERSION_ID < 50519) || \
     defined(MRN_MARIADB_P) || \
     (50600 <= MYSQL_VERSION_ID && MYSQL_VERSION_ID < 50604)
@@ -154,6 +155,12 @@ extern "C" {
 #  define MRN_GET_ERROR_MESSAGE current_thd->main_da.message()
 #endif
 
+#if defined(_WIN32) || defined(_WIN64)
+#  define MRN_API __declspec(dllexport)
+#else
+#  define MRN_API
+#endif
+
 class ha_mroonga;
 
 /* structs */
@@ -472,6 +479,7 @@ protected:
 
 private:
   void mkdir_p(const char *directory);
+  ulonglong file_size(const char *path);
 
   void push_warning_unsupported_spatial_index_search(enum ha_rkey_function flag);
   void clear_cursor();
@@ -579,18 +587,17 @@ private:
   int storage_encode_key_set(Field *field, const uchar *key,
                              uchar *buf, uint *size);
   int storage_encode_key(Field *field, const uchar *key, uchar *buf, uint *size);
-  void storage_encode_multiple_column_key_float(float value,
-                                                uint data_size,
-                                                uchar *buffer,
-                                                bool decode);
-  void storage_encode_multiple_column_key_double(double value,
-                                                 uint data_size,
-                                                 uchar *buffer,
-                                                 bool decode);
   int storage_encode_multiple_column_key(KEY *key_info,
                                          const uchar *key, uint key_length,
                                          uchar *buffer, uint *encoded_length,
                                          bool decode);
+  int storage_encode_multiple_column_key_range(KEY *key_info,
+                                               const key_range *start,
+                                               const key_range *end,
+                                               uchar *min_buffer,
+                                               uint *min_encoded_size,
+                                               uchar *max_buffer,
+                                               uint *max_encoded_size);
 
   void set_pk_bitmap();
   int create_share_for_create() const;
@@ -710,6 +717,9 @@ private:
   ulong storage_index_flags(uint idx, uint part, bool all_parts) const;
   int wrapper_info(uint flag);
   int storage_info(uint flag);
+  void storage_info_variable();
+  void storage_info_variable_records();
+  void storage_info_variable_data_file_length();
   int wrapper_rnd_init(bool scan);
   int storage_rnd_init(bool scan);
   int wrapper_rnd_end();
