@@ -66,7 +66,8 @@
 #  define MRN_DBUG_ENTER_METHOD()                 \
     char method_name[MRN_MESSAGE_BUFFER_SIZE];    \
     method_name[0] = '\0';                        \
-    strcat(method_name, "ha_mroonga::");          \
+    strcat(method_name, MRN_CLASS_NAME);          \
+    strcat(method_name, "::");                    \
     strcat(method_name, __FUNCTION__);            \
     DBUG_ENTER(method_name)
 #else
