@@ -21,6 +21,10 @@
 #ifndef _mrn_table_hpp
 #define _mrn_table_hpp
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include <groonga.h>
 
 typedef struct st_mroonga_share
@@ -112,4 +116,8 @@ void mrn_set_bitmap_by_key(MY_BITMAP *map, KEY *key_info);
 st_mrn_slot_data *mrn_get_slot_data(THD *thd, bool can_create);
 void mrn_clear_alter_share(THD *thd);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _mrn_table_hpp */
